@@ -1,9 +1,11 @@
 use crate::SystemTimeSpec;
 use io_lifetimes::AsFilelike;
-use std::{fs, io, path::Path, time::SystemTime};
+use std::path::Path;
+use std::time::SystemTime;
+use std::{fs, io};
 #[cfg(not(windows))]
 use {
-    posish::{
+    rsix::{
         fs::{cwd, futimens, utimensat, AtFlags},
         fs::{UTIME_NOW, UTIME_OMIT},
         time::Timespec,
